#
# spec file for package fence-agents
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} == 1315
%define python_version python2
%else
%define python_version python3
%endif

%global plugin_dir %{_libdir}/stonith/plugins/rhcs
%define agent_list aliyun alom amt amt_ws apc apc_snmp azure_arm bladecenter brocade cisco_mds cisco_ucs compute docker drac5 dummy eaton_snmp emerson eps evacuate gce hds_cb hpblade ibmblade ibmz ifmib ilo ilo_moonshot ilo_mp ilo_ssh intelmodular ipdu ipmilan ironic kdump ldom lpar mpath netio openstack powerman pve raritan rcd_serial redfish rhevm rsa rsb sanbox2 sbd scsi vbox virsh vmware vmware_rest wti xenapi zvm

Name:           fence-agents
Summary:        Fence Agents for High Availability
License:        GPL-2.0-only AND LGPL-2.1-only
Group:          Productivity/Clustering/HA
Version:        4.9.0+git.1624456340.8d746be9
Release:        lp152.3.15.1
Url:            https://github.com/ClusterLabs/fence-agents
Source0:        %{name}-%{version}.tar.xz
Patch1:         0001-Use-Python-3-for-all-scripts-bsc-1065966.patch

BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  %{python_version}
%if %{python_version} == "python3"
BuildRequires:  python3-google-api-python-client
BuildRequires:  python3-keystoneclient
BuildRequires:  python3-novaclient
BuildRequires:  python3-oauth2client
BuildRequires:  python3-openwsman
BuildRequires:  python3-pexpect
BuildRequires:  python3-pycurl
BuildRequires:  python3-requests
BuildRequires:  python3-xml
%else
BuildRequires:  python-google-api-python-client
BuildRequires:  python-keystoneclient
BuildRequires:  python-novaclient
BuildRequires:  python-oauth2client
BuildRequires:  python-pexpect
BuildRequires:  python-pycurl
BuildRequires:  python-requests
BuildRequires:  python-xml
%endif
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  fdupes
BuildRequires:  glibc-devel
BuildRequires:  libtool
BuildRequires:  libxml2-tools
BuildRequires:  libxslt
BuildRequires:  mozilla-nspr-devel
BuildRequires:  mozilla-nss-devel
BuildRequires:  perl
BuildRequires:  perl-Net-Telnet
BuildRequires:  pkg-config
BuildRequires:  xz

%if %{python_version} == "python3"
Requires:       python3-pexpect
Requires:       python3-pycurl
Requires:       python3-requests
%else
Requires:       python-pexpect
Requires:       python-pycurl
Requires:       python-requests
%endif
Requires:       net-snmp
Requires:       openssh
Requires:       perl-Net-Telnet
Requires:       sg3_utils
Requires:       telnet
Requires:       filesystem

# This is required by fence_virsh. Per discussion on fedora-devel
# switching from package to file based require.
Recommends:     /usr/bin/virsh

# This is required by fence_ipmilan. it appears that the packages
# have changed Requires around. Make sure to get the right one.
Recommends:     /usr/bin/ipmitool

%if %{python_version} == "python3"
Recommends:     python3-openwsman
%endif

%if 0%{?with_regression_tests}
BuildRequires:  time
%endif

%description
Fence agents are device drivers able to prevent computers from
destroying data on shared storage. Their aim is to isolate a
corrupted computer by controlling power, network or storage
configuration. This package provides both a Python API for
creating agents as well as a collection of existing agents.

%package amt_ws
Summary:        Fence Agent for  Intel AMT (WS)
License:        Apache-2.0
Group:          Productivity/Clustering/HA
Requires:       %{name} = %{version}

%description amt_ws
Fence agents are device drivers able to prevent computers from
destroying data on shared storage. Their aim is to isolate a
corrupted computer by controlling power, network or storage
configuration. This packages provides an agent for Intel AMT (WS).

%package devel
Summary:        Fence Agents for High Availability
License:        GPL-2.0-only AND LGPL-2.1-only
Group:          Development/Tools/Other
Requires:       %{name} = %{version}

%description devel
Fence agents are device drivers able to prevent computers from
destroying data on shared storage. Their aim is to isolate a
corrupted computer by controlling power, network or storage
configuration. This package provides agents suitable only for
development.

%prep
%setup -q -n %{name}-%{version}
%if %{python_version} == "python3"
%patch1 -p1
%endif

%build
CFLAGS="${CFLAGS} ${RPM_OPT_FLAGS}"
export CFLAGS
%if %{python_version} == "python3"
PYTHON="%{_bindir}/python3"
%else
PYTHON="%{_bindir}/python2"
%endif
export PYTHON
echo "%{version}" >.tarball-version
./autogen.sh
%{configure} --with-agents='%{agent_list}'
make

%install
make install DESTDIR=%{buildroot}

## tree fix up
# fix libfence permissions
chmod 0755 %{buildroot}%{_datadir}/fence/fenc*.py
# remove docs
rm -rf %{buildroot}/usr/share/doc/fence-agents
# create links to agents in the plugins dir
mkdir -p %{buildroot}%{plugin_dir}
ln -s %{_sbindir}/fence_cisco_ucs %{buildroot}%{plugin_dir}
%fdupes %buildroot%{_sbindir}
%fdupes %buildroot%{_datadir}/cluster

%if 0%{?with_regression_tests}
%check
make check
PYTHONPATH=fence/agents/lib %{python_version} fence/agents/lib/tests/test_fencing.py
%endif

%files
%defattr(-,root,root,-)
%license doc/COPYING.* doc/COPYRIGHT doc/README.licence
%dir %{plugin_dir}
%dir %{_libdir}/stonith/plugins
%dir %{_libdir}/stonith
%{_datadir}/fence
%{_datadir}/cluster
%{plugin_dir}/fence_cisco_ucs
%{_sbindir}/fence_*
%exclude %{_sbindir}/fence_amt_ws
%exclude %{_mandir}/man8/fence_amt_ws*
%exclude %{_sbindir}/fence_dummy
%exclude %{_mandir}/man8/fence_dummy*
%{_mandir}/man8/fence_*
%{_libexecdir}/fence_*
/usr/share/pkgconfig/fence-agents.pc

%files amt_ws
%{_sbindir}/fence_amt_ws
%{_mandir}/man8/fence_amt_ws*

%files devel
%{_sbindir}/fence_dummy
%{_mandir}/man8/fence_dummy*

%changelog
* Thu Jun 24 2021 varkoly@suse.com
- Update to version 4.9.0+git.1624456340.8d746be9:
  * fence_azure_arm: corrections to support Azure SDK >= 15 - including backward compatibility (#415)
    (bsc#1185058)
  * fence_gce: make serviceaccount work with new libraries
  * fence_kubevirt: new fence agent
  * fence_virt*: simple_auth: use %%zu for sizeof to avoid failing verbose builds on some archs
  * configure: dont fail when --with-agents contains virt
  * fence_mpath: watchdog retries support
  * fencing: add multi plug support for reboot-action
  * fence_redfish: add missing diag logic
  * fencing: fix issue with hardcoded help text length for metadata
  * fence_lindypdu: update metadata
  * fence_lindypdu: new fence agent
  * fencing: add stonith_status_sleep parameter for sleep between status calls during a STONITH action
  * fence_openstack: code formatting fixes per: https://github.com/ClusterLabs/fence-agents/pull/397#pullrequestreview-634281798
  * Proper try-except for connection exception.
  * Fix CI.
  * Do not wrap as many values.
  * Restore port metadata.
  * Update xml metadata.
  * Use standard logging.
  * Revert change to __all__
  * fence_virt: fix required=1 parameters that used to not be required and add deprecated=1 for old deprecated params
  * Major rework of the original agent:
  * fence_gce: default method moved back to powercycle (#389)
  * fence_aws: add filter parameter to be able to limit which nodes are listed
  * virt: fix a bunch of coverity scan errors in ip_lookup
  * virt: make sure to provide an empty default to strncpy
  * virt: make sure buffers are big enough for 0 byte end string
  * virt: increase buffer size to avoid overruns
  * virt: check return code in virt-sockets
  * virt: fix error code checking
  * virt: fix plugin (minor) memory leak and plug in load race
  * virt: attempt to open file directly and avoid race condition
  * virt: fix different coverity scan errors in common/tcp
  * virt: cleanup deadcode in client/vsock
  * virt: cleanup deadcode in client/tcp
  * virt: fix potential buffer overrun
  * virt: fix mcast coverity scan errors
  * virt: drop pm-fence plugin
  * build: tidy up module sources
  * virt: drop libvirt-qmf plugin
  * virt: drop null plugin
  * build: enable fence_virtd cpg plugin by default
  * virt: drop fence_virtd non-modular build
  * virt: fix plugin installation regression on upgrades
  * build: temporary disable -Wcast-align for some agents
  * build: fix CFLAGS overrides when using clang
  * fence_virt: metadata fixes, implement manpage generation and metadata/delay/rng checks
  * virt: make sure variable is initialized
  * Drop travis CI
  * Revert "virt: drop -Werror to avoid unnecessary failures"
  * zvm: reformat fence_zvm to avoid gcc warnings
  * build: fix make maintainerclean
  * build: remove unnecessary build snippets
  * virt: drop -Werror to avoid unnecessary failures
  * virt: disable -Wunused for yy generated files
  * virt: disable fence-virt on bsd variants
  * virt: merge spec files
  * build: fix more gcc warnings
  * build: remove unused / obsoleted options
  * build: fix some annoying warnings at ./autogen.sh time
  * virt: move all virt CFLAGS/LDFLAGS in the right location
  * virt: fix unused gcc warnings and re-enable all build warnings
  * virt: fix write-strings gcc warnings
  * virt: fix pointer-arith gcc warnings
  * virt: fix declaration-after-statement gcc warnings
  * virt: fix build with -Wmissing-prototypes
  * build: don´t override clean target
  * virt: plug fence_virt into the build
  * virt: allow fence_virt build to be optional
  * virt: drop support for LSB init script
  * virt: collect docs in one location
  * virt: remove unnecessary files and move build macros in place
  * Ignore fence-virt man pages
  * Merge done
  * Move fence_virt to the correct location
  * Start merge
  * spec: use python3 path for newer releases
  * spec: undo autosetup change that breaks builds w/git commit hashes
  * Ignore unknown options on stdin
  * fence_gce: support google-auth and oauthlib and fallback to deprecated libs when not available
  * spec: add aliyun subpackage and fence_mpath_check* to mpath subpackage
  * fence_gce: Adds cloud-platform scope for bare metal API and optional proxy flags (#382)
  * fence_virt: Fix minor typo in metadata
  * fence_gce: update module reqs for SLES 15 (#383)
  * Add fence_ipmilanplus as fence_ipmilan wrapper always enabling lanplus
  * fence_redfish: Add diag action
  * fence_vbox: updated metadata file
  * fence_vbox: do not flood host account with vboxmanage calls
  * fence_aws/fence_gce: allow building without cloud libs
  * fence_gce: default to onoff
  * fence_lpar: Make --managed a required option
  * fence_zvmip: fix shell-timeout when using new disable-timeout parameter
  * Adds service account authentication to GCE fence agent
  * spec: dont build -all subpackage as noarch
  * fence_virt: add plug parameter that obsoletes old port parameter
  * Try to detect directory for initscripts configuration
  * Accept SIGTERM while waiting for initialization.
  * Add man pages to fence_virtd service file.
  * Fix spelling error in fence_virt.conf.5
  * build: fix BRs for suse distros
  * build: remove ExclusiveArch
  * build: removed gcc-c++ BR
  * build: add spec-file and rpm build targets
  * build: cleanup/improvements to reworked build system
  * [build] rework build system to use automake/libtool
  * fence_virtd: Fix segfault in vl_get when no domains are found
  * fence_virt: fix core dump
  * build: harden and make it possible to build with -fPIE
  * fence_virt: dont report success for incorrect parameters
  * fence_virt: mcast: config: Warn when provided mcast addr is not used
  * fence_virtd: Return control to main loop on select interruption
  * fence-virtd: Add missing vsock makefile bits
  * fence-virt: Add vsock support
  * fence_virtd: Fix transposed arguments in startup message
  * fence_virt: Rename challenge functions
  * fence_virtd: Cleanup: remove unused configuration options
  * fence_virt: Remove remaining references to checkpoints
  * fence_virt: Remove remaining references to checkpoints
  * fence-virt: Format string cleanup
  * fence_virtd: Implment hostlist for the cpg backend
  * fence_virt: Fix logic error in fence_xvm
  * fence_virtd: Cleanup config module
  * fence_virtd: cpg: Fail initialization if no hypervisor connections
  * fence_virtd: Make the libvirt backend survive libvirtd restarts
  * fence_virtd: Allow the cpg backend to survive libvirt failures
  * fence_virtd: cpg: Fix typo
  * fence-virtd: Add cpg-virt backend plugin
  * fence_virtd: Remove checkpoint, replace it with a CPG only plugin
  * fence-virt: Bump version
  * fence_virtd: Add better debugging messages for the TCP listner
  * fence_virtd: Fix potential unlocked pthread_cond_timedwait()
  * fence-virtd: Cleanup small memory leak
  * fence_virtd: Fix select logic in listener plugins
  * Factor out common libvirt code so that it can be reused by multiple backends
  * Document the fence_virtd -p command line flag
  * fence_virtd: Log an error when startup fails
  * Retry writes in the TCP, mcast, and serial listener plugins while sending a response to clients, if the write fails or is incomplete.
  * Make the packet authentication code more resilient in the face of transient failures.
  * Remove erroneous 'inline'
  * Disable the libvirt-qmf backend by default
  * Bump the versions of the libvirt and checkpoint plugins
  * fence-virtd: Enable TCP listener plugin by default
  * fence-virtd: Cleanup documentation of the TCP listener
  * fence_xvm/fence_virt: Add support for the validate-all status op
  * fence-virt: Add list-status command to man page and metadata
  * fence-virt: Cleanup numeric argument parsing
  * fence-virt: Log message to syslog in addition to stdout/stderr
  * fence-virt: Permit explicitly setting delay to 0
  * fence-virt: Add 'list-status' operation for compat with other agents
  * Fix use of undefined #define
  * Allow fence_virtd to run as non-root
  * Remove delay from the status, monitor and list functions
  * Resolves serveral problems in checkpoint plugin, making it functional.
  * Current implementation of event listener in virt-serial does not support keepalive, it does not generate nor capable to answer to keepalive requests, which causes libvirt connection to disconnect every 30 seconds (interval*timeout in libvirtd.conf). Furthermore, it does not clean up filehandlers and leaves hanging sockets. Also, if other thread opens its own connection to libvirt (i.e. checkpoint.c), event function in virt-serial.c just updates event listener file handler with a wrong one, what causes checkpoint.c malfunctions, fence_virtd hangs and so on. This patch uses default event listener implementation from libvirt and resolves theese problems.
  * daemon_init: Removed PID check and update
  * fence_virtd: drop legacy SysVStartPriority from service unit
  * fence-virt: client: Do not truncate VM domains in list output
  * client: fix "delay" parameter checking (copy-paste)
  * fence-virt: Fix broken restrictions on the port ranges
  * Clarify debug message
  * fence-virtd: Use perror only if the last system call returns an error.
  * fence-virtd: Fix printing wrong system call in perror
  * fence-virtd: Allow multiple hypervisors for the libvirt backend
  * fence-virt: Don't overrwrite saved errno
  * fence-virt: Fix small memory leak in the config module
  * fence-virt: Fix mismatched sizeof in memset call
  * fence-virt: Send complete hostlist info
  * fence-virt: Clarify the path option in serial mode
  * Bump version
  * fence-virt: Bump version
  * fence_virtd: Fix broken systemd service file
  * fence_virt/fence_xvm: Print status when invoked with -o status
  * fence-virt: Fix for missed libvirtd events
  * fence-virt: Fail properly if unable to bind the listener socket
  * client: dump all arguments structure in debug mode
  * Drop executable flag for man pages (finally)
  * Honor implicit "ip_family=auto" in fence_xvm w/IPv6 mult.addr.
  * Fix using bad struct item for auth algorithm
  * Drop executable flag for man pages
  * use bswap_X() instead of b_swapX()
  * fence_virtd: Fix memcpy size params in the TCP plugin
  * Revert "fence-virt: Fix possible descriptor leak"
  * fence_virtd: Return success if a domain exists but is already off.
  * fence-virt: Add back missing tcp_listener.h file
  * fence-virt: Fix a few fd leaks
  * fence-virt: Fix free of uninitialized variable
  * fence-virt: Fix possible null pointer dereference
  * fence-virt: Fix memory leak
  * fence-virt: Fix fd leak when finding local addresses
  * fence-virt: Fix possible descriptor leak
  * fence-virt: Fix possible fd leak
  * fence-virt: Fix null pointer deref
  * fence-virt: Explicitly set delay to 0
  * fence-virt: Fix return with lock held
  * fence_virt: Fix typo in fence_virt(8) man page
  * fence_virt: Return failure for nonexistent domains
  * Initial commit
  * Improve fence_virt.conf man page description of 'hash'
  * Add a delay (-w) option.
  * Remove duplicated port struct entry
  * Add a TCP listener plugin for use with viosproxy
  * In serial mode, return failure if the other end closes the connection before we see SERIAL_MAGIC in the reply or timeout.
  * Stop linking against unnecessary QPid libs.
  * Update libvirt-qmf plugin and docs
  * Fix crash when we fail to read key file.
  * Fix erroneous man page XML
  * Add 'interface' directive to example.conf
  * Fix build
  * Add old wait_for_backend directive handling & docs
  * Return proper error if we can't set up our socket.
  * Fix startup in systemd environments
  * Add systemd unit file and generation
  * Don't override user's pick for backend server module
  * Use libvirt as default in shipped config
  * Clean up compiler warnings
  * Fix serial domain handling
  * Fix monolithic build
  * Clean up build and comments.
  * Add missing pm_fence source code
  * Disable CMAN / checkpoint build by default
  * Rename libvirt-qpid -> libvirt-qmf
  * Fix static analysis errors
  * Reword assignment to appease static analyzers
  * Handle return value from virDomainGetInfo
  * Fix bad sizeof()
  * Make listen() retry
  * Add map_check on 'status' action
  * Update README
  * Don't reference out-of-scope temporary
  * Ensure we don't try to strdup() or atoi() on NULL
  * Add libvirt-qmf support to the libvirt-qpid plugin
  * Convert libvirt-qpid plugin to QMFv2
  * Fix incorrect return value on hash mismatch
  * Fix error getting status from libvirt-qpid plugin
  * Fix typo that broke multicast plugin
  * Make fence-virt requests endian clean
  * Update TODO
  * Fix input parsing to allow domain again
  * Provide 'domain' in metadata output for compatibility
  * High: Fix UUID lookups in checkpoint backend
  * Curtail 'list' operation requests
  * Fix man page references: fence_virtd.conf -> fence_virt.conf
  * Add 'list' operation for plugins; fix missing getopt line
  * Fix build with newer versions of qpid
  * Make configure.in actually disable plugins
  * Fix metadata output
  * Rename parameters to match other fencing agents
  * Fix fence_xvm man page to point to the right location
  * client: Clarify license in serial.c
  * Return 2 for 'off' like other fencing agents
  * Reset flags before returning from connect_nb
  * Use nonblocking connect to vmchannel sockets
  * More parity with other fencing agents' parameters
  * Fix memory leaks found with valgrind
  * Add basic daemon functions
  * Fix bug in path pruning support for serial plugin
  * Fix libvirt-qpid bugs found while testing
  * Fix segfault caused by invalid map pointer assignment
  * Fix another compiler warning
  * Fix build warnings in client/serial.c
  * Add 'monitor' as an alias for 'status'
  * Add serial listener to configuration utility
  * Make serial/vmchannel module enabled by default
  * Add missing 'metadata' option to help text
  * Add missing static_map.h
  * Add metadata support to fence_xvm/fence_virt
  * Allow IPs to be members of groups
  * Allow use of static mappings w/ mcast listener
  * Make 'path' be a directory
  * Update TODO
  * Remove useless debug printfs
  * Enable VM Channel support in serial plugin
  * Update TODO based on progress
  * Pass source VM UUID (if known) to backend
  * Mirror libvirt-qpid's settings in libvirt-qpid plugin
  * libvirt-qpid: clean up global variable
  * Enable a configurable host/port on libvirt-qpid plugin
  * Minor config utility cleanups
  * Man page cleanups
  * Remove unnecessary name_mode from multicast plugin
  * Add prototypes and clean up build warnings
  * Use seqno in serial requests
  * Minor debugging message cleanup
  * Fix build error due to improper value
  * Static map support and permissions reporting
  * Sync up on SERIAL_MAGIC while waiting for a response
  * Don't build serial vmchannel module by default
  * Update TODO
  * Initial checkin of serial server-side support
  * Fix fence_virt.conf man page name
  * Add Fedora init script
  * Compiler warning cleanups in virt-serial.c
  * Add wait-for-backend mode
  * Fix up help text for clients
  * Minor XML cleanups, add missing free() call
  * add missing module_path to fence_virtd.conf.5
  * Add capabilities to virt-serial
  * Note that serial support is experimental
  * Add a serial.so build target
  * Add vmchannel serial event interface
  * Split fence_virt vs. fence_xvm args
  * Add static map functions.
  * Fix build warning due to missing #include
  * Fix multiple query code
  * Better config query & multiple value/tag support
  * Add simple configuration mode
  * Add missing man pages
  * More minor config cleanups
  * Allow setting config values to NULL to clear them
  * Clean up example config file
  * Sort plugins by type when printing them
  * Revert "Sort plugins by type when printing them"
  * Sort plugins by type when printing them
  * Clean up some configuration plugin information
  * add empty line between names
  * Make libvirt to automatically use uuid or names
  * Improve error reporting
  * Fix build for hostlist functionality
  * Hostlist functionality for libvirt, libvirt-qpid
  * Update TODO
  * Work around broken nspr headers
  * Fix installation target for man pages
  * Fix default build script
  * Add man page build infrastructure
  * Initial commit of fence_virt & fence_xvm man pages
  * Make fence_xvm compatibility mode enabled by default
  * Fix libvirt / mcast support for name_mode
  * Fix agent option parsing
  * Fix dlsym mapping of C++ module
  * Make uuids work with libvirt-qpid
  * Fix uninitialized variable causing false returns
  * Update monolithic build
  * Fix linking problem
  * Add 'help' to fence_virtd
  * Fix libvirt-qpid build
  * Make 'reboot' work
  * Fix libvirt-qpid build
  * Add libvirt-qpid build target
  * Initial checking of libvirt-qpid plugin
  * Fix build on i686
  * Make symlink/compatibilty mode disabled by default
  * Add simple tarball / release script
  * Update TODO and requirements file
  * Update TODO
  * Use immediate resolution of symbols
  * Example config tweaks
  * Use sysconfdir for /etc/fence_virt.conf
  * Fix package name and install locations
  * Fix daemon return code
  * Add 'maintainer-clean' target
  * Fix build errors on Fedora
  * Add missing header file
  * Ignore automake error
  * Add missing COPYING file; update TODO
  * Make the build script actually build
  * Make cluster mode plugin work
  * Add basic cpg stuff for later
  * Enable 'on' operation for libvirt backend
  * Clean up modular build
  * Minor build cleanups
  * Yet more build fixes
  * More build cleanups
  * Build cleanups
  * Initial port to autoconf
  * Add checkpoint.c stub functions
  * Add sequence numbers to requests for tracking
  * Include missing include
  * Call generic history functions
  * Make history functions generic
  * Make debugging work from modules again
  * Revert "Fix build issue breaking debug printing from modules"
  * Fix build issue breaking debug printing from modules
  * Fix libvirt backend; VALIDATE was wrong
  * Cleanups, add daemon support
  * Add simple 'null' skeleton backend plugin
  * Make all plugins dynamically loaded.
  * Fix error message
  * Remove dummy serial prototypes
  * Remove modules in 'make clean'
  * Make listeners plugins.
  * Fix whitespace
  * Move name_mode to fence_virtd block
  * Add name_mode to example.conf
  * Move VM naming scheme to top level of config
  * Fix bad assignment due to wrong variable
  * Fix use of wrong variable
  * Revert "Fix use of wrong variable"
  * Fix use of wrong variable
  * Enable UUID use in libvirt.c
  * Add missing log.c.  Enable syslog wrapping
  * Move options.c to client directory
  * Fix context type names
  * Minor cleanup
  * Drop duplicate fencing requests
  * Don't require specifying an interface in fence_virt.conf
  * Fix empty node parsing
  * Fix segfault
  * Fix install targets
  * Actually use the default port by default
  * Don't overwrite config files
  * Install modules, too.
  * Fix config file name
  * Add temporary 'make install' target
  * Make a default configuration file
  * Make mcast work with UUIDs
  * Update TODO
  * Remove useless prototype
  * Update todo
  * Add checkpoint.so to the build
  * Fix missing carriage returns on debug prints
  * Add architecture overview description
  * Make serial_init match mcast_init.
  * Make multicast use config file
  * Integrate config file processing
  * Create server-side plugin architecture
  * Remove bad list_do/list_done macros
  * Make libvirt a built-in plugin
  * Update description text.
  * Fix header in serial.c.
  * serial: Make client work.
- remove patch contained by the update:
  - 0001-Adds-service-account-authentication-to-GCE-fence-age.patch
  (jsc#SLE-18182) ECO: Update fence-agents
  (jsc#SLE-18027) Add upstream PR to aws-vpc-move-ip and apply required resource & fence agent patches
* Tue Jan 26 2021 Peter Varkoly <varkoly@suse.com>
- bsc#1180518 [15sp3 FEAT] Product-HA / High Availability Extension:
  Add IBM Z LPAR fence agent fence_ibmz to Pacemaker (kvm) (fence-agents)
* Fri Jan 22 2021 Peter Varkoly <varkoly@suse.com>
- (bsc#1178343) `fence_gce` updates to be pulled to the SLE versions
  The last update broke fencing in GCE
  * add-upstream patch
    0001-Adds-service-account-authentication-to-GCE-fence-age.patch
- Update to version 4.7.0+git.1607346448.17bd8552:
  * fence_mpath, fence_scsi: Improve logging for failed res/key get
  * fence_mpath, fence_scsi: Capture stderr in run_cmd()
  * build: depend on config changes to rebuild when running make after running ./configure
  * fence_redfish: Fix typo in help.
  * fence_aws: add support for IMDSv2
* Fri Nov 20 2020 varkoly@suse.com
- (bsc#1178343) `fence_gce` updates to be pulled to the SLE versions
- Update to version 4.6.0+git.1605185986.7b0f11c1:
  * spec: add pkg-config file, and set version for obsoletes to avoid failing to build on Fedora 33
  * Add pkg-config file
  * fence_scsi: dont write key to device if it's already registered, and open file correctly to avoid using regex against end-of-file
  * fencing: fix run_command() to allow timeout=0 to mean forever
  * fencing: fix to make timeout(s)=0 be treated as forever for agents using pexpect
  * Add a fence_crosslink agent
  * fencing: fix power-timeout when using new disable-timeout parameter
  * spec: make telnet a weak dependency
- remove patch contained by the update:
  - 0001-Update-fence_aliyun.py-279.patch
  - 0001-Update-fence_aliyun.xml.patch
  - gcp-vpc-move-disable-google-api-cache-discovery.patch
  - fence_vmware_rest-improve-exception-handling-in-send_command.patch
* Thu Apr 30 2020 Peter Varkoly <varkoly@suse.com>
- Disable cache discovery for "gcp-vpc-move-route" resource agent
  (bsc#1169852)
- fence_vmware_rest Failed: 'error' object does not support indexing
  (bsc#1169485)
- Included following upstream patch:
  gcp-vpc-move-disable-google-api-cache-discovery.patch
  fence_vmware_rest-improve-exception-handling-in-send_command.patch
* Thu Sep 12 2019 Peter Varkoly <varkoly@suse.com>
- bsc#1150504 - aliyun: Include the latest fixes upstream on the
  Alibaba Cloud fence-agent.
  add patches 0001-Update-fence_aliyun.py-279.patch
    0001-Update-fence_aliyun.xml.patch
* Mon Jul  1 2019 Diego Vinicius Akechi <dakechi@suse.com>
- White list the aliyun fence agent to get it included and provided
  by the fence-agent package (bsc#1139913)
* Wed Jun 12 2019 kgronlund@suse.com
- Split fence_amt_ws into separate package due to licence incompatibility:
  * Apache-2.0 is not compatible with GPL-2.0
- Update to version 4.4.0+git.1558595666.5f79f9e9:
  * fence_scsi: detect node ID using new format, and fallback to old format before failing
  * fence_rhevm: fix debug encoding issues (bsc#1137314) (CVE-2019-10153)
  * fence_mpath: import ctypes to fix watchdog hardreboot
  * fence_rhevm: add RHEV v4 API support and auto-detection
  * fence_azure_arm: use skip_shutdown feature when available
  * fence_ipmilan: Add ipmitool timeout option
  * fence_redfish: add headers to HTTP methods
  * fence_gce: fix Python 3 encoding issue
  * fence_pve: add support for sending reset command to qemu machines (#261)
  * fencing: improve stdin parse function
  * fence_redfish: backwards compatibility for <ip>:<port>
* Mon Feb 18 2019 dakechi@suse.com
- Update to version 4.2.1+git.1550476590.98767d24:
  * fence_redfish: use "ipport" parameter and improve logging (fate#320898)
  * Changed Encoding to UTF-8 (bsc#1137314) (CVE-2019-10153)
  * fence_redfish: fail when using invalid cert without --ssl-insecure (fate#320898)
  * Removed unnecessary variable assignments to simplify code
  * fence_scsi: watchdog retries support
  * Renamed variable to avoid reusing variable name
  * Replaced default port 443 with default ssl enabled option
  * Changed reboot type to ForceRestart
  * Modify power status check
  * Added run_delay()
  * Updated fence_redfish.xml with make xml-upload (fate#320898)
  * Add new fence agent for Redfish (fate#320898)
  * build: fix issues with newer autoconf versions
  * build: fix if-redirection to make check_used_options run for the agents as intended
  * Fix 'log_expect' in fence_hpblade.py
  * fence_scsi: fix incorrect SCSI key when node ID is 10 or higher
  * fence_openstack: add detection of keystoneauth1 library
  * check_used_options: add Python 3 support, and detect unsupported has_key()-calls
  * fence_openstack: Migrate from keystoneclient to keystoneauth1
  * fence_openstack: fix missing version parameter in novaclient.Client() call
  * fence_openstack: fix configure library detection and add try/except for imports
  * fence_kdump: add validate-all action
  * fence_compute/fence_evacuate: domain parameter fixes to avoid regressions
* Wed Sep 26 2018 kgronlund@suse.com
- Update to version 4.2.1+git.1537269352.7b1fd536:
  * fence_vmware_soap: cleanup when receiving SIGTERM
  * fence_cisco_ucs: encode POSTFIELDS
  * Update fence_rcd_serial to correct vendor URL
  * fence_aliyun: correct indentation for *key in help
  * fence_aliyun: list instance names and show up to 100 instances (fate#326557)
  * fence-rhevm: improve error reporting.
  * fence_impilan/fence_ilo_ssh: iLO5-support
  * fence_rhevm: improve indentation and metadata
  * fence_compute/fence_evacuate/fence_rhevm: dont use has_key (not supported in Python 3)
  * fence_rhevm fixing help for plug param
  * fence_kdump: fix strncpy issue
  * fence_evacuate: fix evacuable tag mix issue
* Thu Aug  9 2018 kgronlund@suse.com
- Update to version 4.2.1+git.1532964592.3ae5b58e:
  * fence_aliyun: Add Aliyun fence agent. (fate#326557)
  * fence_gce: add power cycle as default method
  * fence_gce: set project and zone as not required
  * fence_gce: add support for stackdriver logging
  * fence_ilo3/fence_ipmilan: show correct default method (onoff) in help
  * fence_mpath: add watchdog support
  * fence_amt_ws: create metadata without agent specific libs
- Drop obsolete patch:
  * Remove 0002-Build-without-openwsman-installed.patch
* Wed Jun 27 2018 kgronlund@suse.com
- Unify source package with SLE 12 and Leap 42:
  * fencing: include timestamps when logging to STDERR and debug file (bsc#1049852)
- Obsoletes the following patches (SLE 12 and Leap 42):
  * 0001-fence_compute-Only-list-nova-compute-services-when-g.patch
  * 0002-fence_compute-Don-t-list-hypervisors-but-nova-comput.patch
  * 0003-fence_compute-Do-not-override-domain-if-it-is-alread.patch
  * 0004-fence_compute-Fix-handling-of-domain-None.patch
  * 0005-fence_compute-Fix-fix_domain-to-not-return-too-early.patch
  * 0006-fence_compute-Fix-fix_plug_name-when-looking-if-plug.patch
  * 0007-fence_compute-Remove-duplicate-check-for-binary-name.patch
  * 0009-fence_compute-Fix-disabling-force_down-on-node-when-.patch
  * 0010-Make-pywsman-dependency-optional.patch
  * 0011-fencing-include-timestamps-when-logging-to-STDERR-an.patch
* Mon Jun 25 2018 kgronlund@suse.com
- Unify spec file for python 2 and 3
- Enable build for python 2
  * Add 0002-Build-without-openwsman-installed.patch
* Wed Jun 20 2018 kgronlund@suse.com
- Update to version 4.2.1+git.1529316875.1a39345b:
  * fence_vmware_soap: fix Python 3 suds issue
  * Added python-novaclient and python-keystoneclient in configure.ac
  * novaclient 1.1 depcrecated, so making changes for novaclient
  * Python keystoneclient also included to pacify CI
  * Changed travis to include pythomn-novaclient
  * Fencing Agent for Openstack
  * fence_scsi: fix python3 encoding error #206
  * fence_ipmilan: add missing fence_ilo3 and fence_ilo4 metadata
  * fence_scsi: match device names using re.MULTILINE to avoid duplicating names in /var/run/cluster/fence_scsi.dev
  * fence_gce: use default credentials from googleapiclient
  * run_command: fix Python 3 encoding issue
- Drop merged patches:
  * Remove 0002-fence_gce-fix-regression-missing-import-googleapicli.patch
  * Remove 0003-fence_gce-fix-regression-missing-import-oauth2client.patch
  * Remove 0004-fence_gce-use-default-credentials-from-googleapiclie.patch
  * Remove 0005-run_command-fix-Python-3-encoding-issue.patch
- Enable GCE fence agent for all targets (fate#325539) (bsc#1088358)
- Enable fence_openstack agent (bsc#1097803)
* Thu May 17 2018 kgronlund@suse.com
- run_command: fix Python 3 encoding issue (bsc#1082871)
- fence_gce: use default credentials from googleapiclient
- fence_gce: fix regression - missing import oauth2client.client
- fence_gce: fix regression - missing import googleapiclient.discovery
- Add 0002-fence_gce-fix-regression-missing-import-googleapicli.patch
- Add 0003-fence_gce-fix-regression-missing-import-oauth2client.patch
- Add 0004-fence_gce-use-default-credentials-from-googleapiclie.patch
- Add 0005-run_command-fix-Python-3-encoding-issue.patch
* Thu Apr 26 2018 kgronlund@suse.com
- Update to version 4.0.25+git.1524215631.8f9c770a:
  * fence_gce: Write error messages to log (fate#325539) (bsc#1088358)
  * fence_azure_arm: fix subscriptionId from metadata (bsc#1090995)
  * fence_scsi: fix plug-parameter and keep support for nodename to avoid regressions
* Wed Apr 25 2018 kgronlund@suse.com
- Disable Google Compute Engine support unless openSUSE (fate#325539) (bsc#1088358)
* Wed Apr 11 2018 kgronlund@suse.com
- Update to version 4.0.25+git.1523367910.7473fab7:
  * Add fence_gce: Google Compute Engine fence support (fate#325539) (bsc#1088358)
  * Low: fence_scsi: Remove period from cmd string
  * fence_compute/fence_evacuate: revert to old parameters
  * fence_azure_arm: implement network-fencing (w/library from @MSSedusch)
  * fence_mpath: Correction of command line which argument is not correctly recognized
  * Mid: fence_docker: Exclude slashes from the list.
  * fence_pve : choose vm type either lxc or qemu
* Mon Feb 12 2018 kgronlund@suse.com
- Update to version 4.0.25+git.1518188333.853850c3:
  * heuristics_ping: fix for python3 TypeError
* Wed Feb  7 2018 kgronlund@suse.com
- Update to version 4.0.25+git.1516265527.7ab202cf (bsc#1074000):
  * fence_ilo3: default to onoff
  * fence_compute: Add support for keystone v3 authentication
  * fence_ilo_ssh: fix hard reset
  * fence_vmware_rest: new agent
* Tue Nov 21 2017 kgronlund@suse.com
- Recommend openwsman-python3, not python-openwsman (bsc#1069137)
* Wed Nov  1 2017 kgronlund@suse.com
- Update to version 4.0.25+git.1509350522.8d6f8530 (bsc#1065966):
  * Use Python 3 for all scripts
  * compute: Fix unfencing and ensure fencing occurs in partial up/down states
  * compute: Split out evacation functionality
  * compute: Handle differences in Nova API argument passing
  * fence_zvm: fix "uintptr_t" undeclared
  * fence_ifmib: fix README typo(s)
- Add patch:
  * 0001-Use-Python-3-for-all-scripts-bsc-1065966.patch
- Remove merged patches:
  * 0001-fence_compute-Only-list-nova-compute-services-when-g.patch
  * 0002-fence_compute-Don-t-list-hypervisors-but-nova-comput.patch
  * 0003-fence_compute-Do-not-override-domain-if-it-is-alread.patch
  * 0004-fence_compute-Fix-handling-of-domain-None.patch
  * 0005-fence_compute-Fix-fix_domain-to-not-return-too-early.patch
  * 0006-fence_compute-Fix-fix_plug_name-when-looking-if-plug.patch
  * 0007-fence_compute-Remove-duplicate-check-for-binary-name.patch
  * 0009-fence_compute-Fix-disabling-force_down-on-node-when-.patch
* Sat Sep  9 2017 kgronlund@suse.com
- Move to python3
* Tue Aug 29 2017 kgronlund@suse.com
- Remove deprecated agents
  * Remove fence_ovh
  * Remove fence_drac
  * Remove fence_vmware_soap
- Drop build dependency on python-suds
- Update package description
* Mon Aug 28 2017 kgronlund@suse.com
- Update to version 4.0.25+git.1501671877.7bae40a0:
  * fence_ipmilan: add target support
  * Explicitly use version 3 of the oVirt API
  * fence_rhevm: fix "--api-path must not have an argument" issue
  * Convert URLs passed to pycurl to ASCII
  * fence_vbox: Add support for host on MacOS
  * fence_vbox: Add support for Windows host
  * fence_compute: fix to avoid breaking nova
  * fence_ipmilan: fix target support
  * fence_vmware_soap: fix for selfsigned certificate
  * fence_ipmilan: Add support for hexadecimal format of Kg key
  * fence_azure_arm: fix hardcoded path
  * fence_azure_arm: remove release/build info
  * fence_ipmilan: Fix inconsistency between help and manual page (defalt for --method)
  * fence_scsi: add FIPS support
  * fence_ipmilan: fix indentation
  * fencing_snmp: fix timemout typo
- Drop outdated patch:
  * 0010-Make-pywsman-dependency-optional.patch
* Tue Feb 14 2017 kgronlund@suse.com
- Downgrade some agent-specific dependencies to recommends (bsc#1025149)
  * Add 0010-Make-pywsman-dependency-optional.patch
* Wed Feb  1 2017 kgronlund@suse.com
- Update to version 4.0.25+git.1485179354.eb43835:
  * Ironic fence agent
  * fencing: Add --quiet option to disable logging to stderr
  * fence_powerman: fix typo in option powerman-path
  * fence_cisco_ucs: Commands sent to Cisco UCS are changed to
- Drop merged patch:
  * Remove 0008-Fix-travis.patch
* Thu Dec  1 2016 kgronlund@suse.com
- Update to version 4.0.24+git.1480563949.e67fcd4:
  * fence_azure_arm: add fencing agent for Azure Resource Manager
  * fence_lpar: Add support for IVM
  * fence_lpar: Handle exceptions when invalid output is read
  * fence_zvmip: Update XML metadata
  * fence_compute: fix ConnectionError by using full module name
  * fence_powerman: add fence agent for powerman
  * Suppress InsecureRequestWarning when ssl_insecure is given
  * compute: Correctly handle installations without tagged flavours
  * compute: Use the best available nova API version
  * compute: correctly implement 'on' when the force-down API call is available
  * compute: Correctly identify when the nodename already includes the supplied domain
  * compute: Ensure we can connect to nova when fixing the plug name
  * compute: Simpler check for nova force down compatibility
- Rebase and remove merged patches:
  * Remove 0001-fence_compute-Create-nova-client-with-API-2.11.patch
  * Remove 0002-fence_compute-Keep-compatibility-with-python-novacli.patch
  * Remove 0003-fence_compute-Only-list-nova-compute-services-when-g.patch
  * Remove 0004-fence_compute-Don-t-list-hypervisors-but-nova-comput.patch
  * Remove 0005-fence_compute-Do-not-override-domain-if-it-is-alread.patch
  * Remove 0006-fence_compute-Fix-use-of-undefined-variable.patch
  * Remove 0007-fence_compute-Fix-fix_domain-to-not-return-too-early.patch
  * Remove 0008-fence_compute-Fix-fix_plug_name-when-looking-if-plug.patch
  * Add 0001-fence_compute-Only-list-nova-compute-services-when-g.patch
  * Add 0002-fence_compute-Don-t-list-hypervisors-but-nova-comput.patch
  * Add 0003-fence_compute-Do-not-override-domain-if-it-is-alread.patch
  * Add 0004-fence_compute-Fix-handling-of-domain-None.patch
  * Add 0005-fence_compute-Fix-fix_domain-to-not-return-too-early.patch
  * Add 0006-fence_compute-Fix-fix_plug_name-when-looking-if-plug.patch
  * Add 0007-fence_compute-Remove-duplicate-check-for-binary-name.patch
  * Add 0008-Fix-travis.patch
* Fri Aug 26 2016 kgronlund@suse.com
- Update to version 4.0.24:
  * Improve obtaining status on Cisco UCS devices
  * Fix issues with symlink installations
  * Fix documentation for fence_scsi and fence_mpath
* Thu Jun 30 2016 kgronlund@suse.com
- Update to version 4.0.23:
  * A lot of changes in fence_compute (OpenStack compute instance)
  * Obtain status of nodes from Cisco UCS correctly
  * New fence agent for AMT using openwsman
  * Python3 support
  * Fence agent for PVE can be used by non-root users
  * Parallel building and testing of fence agents
  * Fix occasional failures of APC fence agent
- Updated fence_compute patch set:
  - Add 0001-fence_compute-Create-nova-client-with-API-2.11.patch
  - Add 0002-fence_compute-Keep-compatibility-with-python-novacli.patch
  - Add 0003-fence_compute-Only-list-nova-compute-services-when-g.patch
  - Add 0004-fence_compute-Don-t-list-hypervisors-but-nova-comput.patch
  - Add 0005-fence_compute-Do-not-override-domain-if-it-is-alread.patch
  - Add 0006-fence_compute-Fix-use-of-undefined-variable.patch
  - Add 0007-fence_compute-Fix-fix_domain-to-not-return-too-early.patch
  - Add 0008-fence_compute-Fix-fix_plug_name-when-looking-if-plug.patch
  - Add 0009-fence_compute-Fix-disabling-force_down-on-node-when-.patch
  - Remove 0001-fence_compute-Add-insecure-command-line-argument.patch
  - Remove 0002-fence_compute-Add-region-name-command-line-argument.patch
  - Remove 0003-fence_compute-Create-nova-client-with-API-2.11.patch
  - Remove 0004-fence_compute-Fix-disabling-force_down-on-node-when-.patch
  - Remove 0005-fence_compute-Evacuate-instances-on-all-tenants.patch
  - Remove 0006-fence_compute-On-list-don-t-list-hypervisors-but-nov.patch
  - Remove 0007-fence_compute-Only-list-nova-compute-services-when-g.patch
  - Remove 0008-fence_compute-Deprecate-the-domain-option.patch
* Mon Feb 22 2016 kgronlund@suse.com
- Update to version 4.0.22+git.1455008135.15c5e92:
  + fence_cisco_ucs: Obtain status of device from different endpoint
  + fence_cisco_ucs: Add --missing-as-off
- Backport fence_compute (fate#320346) (bsc#964748)
- Patches for fence_compute (fate#320346) (bsc#964748)
  - fence_compute: Add --insecure command line argument
  - fence_compute: Add --region-name command line argument
  - fence_compute: Create nova client with API 2.11
  - fence_compute: Fix disabling force_down on node when action is on
  - fence_compute: Evacuate instances on all tenants
  - fence_compute: On list, don't list hypervisors but nova-compute services
  - fence_compute: Only list nova-compute services when getting status
  - fence_compute: Deprecate the domain option
- Add 0001-fence_compute-Add-insecure-command-line-argument.patch
- Add 0002-fence_compute-Add-region-name-command-line-argument.patch
- Add 0003-fence_compute-Create-nova-client-with-API-2.11.patch
- Add 0004-fence_compute-Fix-disabling-force_down-on-node-when-.patch
- Add 0005-fence_compute-Evacuate-instances-on-all-tenants.patch
- Add 0006-fence_compute-On-list-don-t-list-hypervisors-but-nov.patch
- Add 0007-fence_compute-Only-list-nova-compute-services-when-g.patch
- Add 0008-fence_compute-Deprecate-the-domain-option.patch
* Wed Jan 27 2016 kgronlund@suse.com
- Package fence_dummy in fence-agents-devel package
- Clean up package
* Wed Jan 13 2016 kgronlund@suse.com
- Update to 4.0.22:
  * New fence agent for VirtualBox
  * A lot of changes in fence_compute (OpenStack)
  * Re-enable fence_zvm
  * Support for APC firmware v6.x
  * Add hard-reboot option for fence_scsi_check script
  * Add option for setting Docker Remote API version
  * Fix HP Brocade fence agent (timeout settings, deprecated options)
  * New action 'diag' for fence_ipmi
* Mon Oct 12 2015 aspiers@suse.com
- Update to 4.0.21:
  * Documentation of new actions in manual pages is improved
  * Tests were improved and Travis CI is now used for every push
  * fence_virsh has new option --missing-as-off to support older XEN hosts
  * fence_ilo(2) now automatically attempts to use TLS1.0 if it is not
    possible to connect via SSLv3
  * fence_mpath re-create SCSI keys after reboot, monitoring of devices
    were improved too
* Tue Aug 11 2015 kgronlund@suse.com
- Update to 4.0.20:
  * In some cases password string was expected twice what lead to 'Unable
    to login'
  * New fence agent fence_rcd_serial for DYI fence device (look at
    https://smcleod.net/rcd-stonith/ ; thanks to Sam McLeod)
  * Fence_pve should default to SSL (thanks to Thomas Lamprecht)
  * Fixes nroff error for fence_virsh (thanks to Adrian Vondendriesch)
  * Improve monitoring for fence_scsi
  * Fixes for devices which do not have port and obtaining status is not
    possible
  * fence_ipmilan no longer print password to debug info
  * Possibility to do force-ON even if device is already ON
  * Possibility to declare that device does not have ON or OFF (usually
    only reboot works)
* Wed Jul  1 2015 kgronlund@suse.com
- Update to 4.0.19:
  * New fence agent for Nova compute machines (thanks to Andrew
    Beekhof and Fabio)
  * Fixed issues with whitespaces in few fence agents (thanks to
    Christoph Berg)
  * User of RHEV-M can have less privileges with updated
    fence_rhevm (thanks to Rik Theys)
  * Verbose output now captures also text before command prompt is
    found
  * Support for HP Integrity Superdome X was added to fence_hpblade
    (thanks to Han Pilmeyer)
  * Fence agent for IBM z/VM now uses API that require less resource
    of device
* Wed Jun 10 2015 kgronlund@suse.com
- Update to 4.0.18:
  * fence_scsi has now implemented action 'monitor'
    (thanks to John Ruemker)
  * fence_scsi is now able to unfence devices added later
    (thanks to John Ruemker)
  * simplification of code thanks to auto-generation of help texts
  * when 'name' is entered on STDIN instead of 'name=value', warning
    is generated
* Tue Apr  7 2015 kgronlund@suse.com
- Update to 4.0.17:
  * HP iLO2 with firmware 2.27 has broken implementation of TLS negotation
    and SSLv3 is disabled by default (POODLE attack). Options --tls1.0
    (tls1.0 on stdin) was added to force using TLS v1.0. This options allows
    users to use that firmware with fence agents.
  * Fence agent for AMT password was not put correctly into environment.
  * Fix login process on bladecenter where 'last login' can occur in
    message of the day what mislead fence agent.
  * Cipher for fence_ipmilan was previously set to 0. It was found out
    that this not good default value, we will use default value (3) of
    ipmitool instead.
* Mon Mar  9 2015 kgronlund@suse.com
- Update to 4.0.16:
  * fence_kdump has implemented 'monitor' action that check if local node
    is capable of working with kdump
  * path to smnp(walk|get|set) can be set at runtime
  * new operation 'validate-all' for majority of agents that checks if
    entered parameters are sufficient without connecting to fence
    device. Be aware that some checks can be done only after we receive
    information from fence device, so these are not tested.
  * new operation 'list-status' that present CSV output (plug_number,
    plug_alias, plug_status) where status is ON/OFF/UNKNOWN
* Mon Feb  9 2015 kgronlund@suse.com
- Update to 4.0.15:
  * Tripp Lite PDUs are now supported by fence_tripplite_snmp (symlink to
    fence_apc_snmp)
  * Default values in metadata sometimes differ to those actually used,
    this is fixed now
  * improvements in testing
- Remove patch: 0001-Avoid-problem-with-broken-make-variable-expansion.patch
* Wed Jan  7 2015 kgronlund@suse.com
- Update to 4.0.14:
  * fence_zvmip for IBM z/VM is rewritten to Python
  * new fence agent for Emerson devices
  * fix invalid default ports for fence_eps and fence_amt
  * properly escape XML in other fields of metadata
  * a lot of refactoring and cleaning
* Mon Dec 15 2014 kgronlund@suse.com
- Update to 4.0.13:
  * new fence agent based on mpathpersist that offers better handling of
    multipath devices
  * improve support of fence_ilo_ssh on older firmwares
  * required packages are also required by autoconf during build time
  * fence_zvm now supports action 'monitor' (thanks to Neale Ferguson)
  * introduce --gnutlscli-path --sudo-path --ssh-path and --telnet-path;
    they are no longer hard-coded
  * order of XML parameters or options in --help is more stable now
  * fence_cisco_ucs did not set protocol prefix correctly with
  - -ssl-(in)secure
  * logging to syslog now works correctly also with \x00 as input
- Add patch: 0001-Avoid-problem-with-broken-make-variable-expansion.patch
* Thu Oct 16 2014 kgronlund@suse.com
- Update to 4.0.12:
  * new up-to-date wiki page with STDIN / command line arguments
    http://fedorahosted.org/cluster/wiki/FenceArguments
  * Fence agent fence_pve now supports --ssl-secure and --ssl-insecure
  (check certificate or not)
  * Fence agent for RHEV-M supports cookie based authentication
  (--use-cookies)
  * improvements in build system
  * Fix issue with regular expression in fence_rsb
  * Fix uninitialized EOL in fence_wti
- Remove backported patches:
  - 0001-fence_brocade-Add-support-for-list-action.patch
  - 0002-fencing-Monitor-is-not-working-correctly-without-lis.patch
  - 0003-fence_apc_snmp-Add-support-for-firmware-6.x.patch
  - 0004-fence_zvm-Add-support-for-on-and-status.patch
  - 0005-fence_zvm-Add-current-XML-metadata-to-test-suite.patch
  - 0006-build-Fix-automake-files-so-make-distcheck-works.patch
  - 0007-fencing-Add-new-options-ssl-secure-and-ssl-insecure.patch
  - 0008-tests-Update-XML-metadata-of-fence-agents.patch
  - 0009-fence_cisco_ucs-fence_vmware_soap-Logout-has-to-be-p.patch
  - 0010-fence_zvm-Fixes-for-better-upstream-inclusion.patch
  - 0011-fence_zvm-Add-support-for-on-improve-documentation.patch
  - 0012-fence_rhevm-Use-https-prefix-also-with-ssl-secure-an.patch
  - 0013-fence_apc-shell-timeout-was-used-instead-of-power-ti.patch
  - 0014-fence_rsb-Fix-62d90e3a0827fcdc5be632bdf4103d3c08b396.patch
  - 0015-fence_wti-Fix-invalid-eol.patch
  - 0016-fence_pve-Add-support-for-ssl-secure-and-ssl-insecur.patch
* Mon Oct 13 2014 kgronlund@suse.com
- Backport security and bug fixes (bnc#900879) (CVE-2014-0104)
  - fence_rhevm: Use https:// prefix also with --ssl-secure and --ssl-insecure
  - fence_apc: --shell-timeout was used instead of --power-timeout
  - fence_rsb: Fix 62d90e3a0827fcdc5be632bdf4103d3c08b39622
  - fence_wti: Fix invalid "eol"
  - fence_pve: Add support for --ssl-secure and --ssl-insecure
- Added patches:
  - 0012-fence_rhevm-Use-https-prefix-also-with-ssl-secure-an.patch
  - 0013-fence_apc-shell-timeout-was-used-instead-of-power-ti.patch
  - 0014-fence_rsb-Fix-62d90e3a0827fcdc5be632bdf4103d3c08b396.patch
  - 0015-fence_wti-Fix-invalid-eol.patch
  - 0016-fence_pve-Add-support-for-ssl-secure-and-ssl-insecur.patch
* Fri Oct  3 2014 kgronlund@suse.com
- Add requirement for python-suds (bnc#899664)
* Tue Sep 16 2014 kgronlund@suse.com
- Backport fixes from upstream (bnc#896833):
  + fence_brocade: Add support for 'list' action
  + fencing: Monitor is not working correctly without 'list' or 'status'
  + fence_apc_snmp: Add support for firmware 6.x
  + fence_zvm: Add support for "on" and "status"
  + fence_zvm: Add current XML metadata to test suite
  + [build] Fix automake files, so 'make distcheck' works
  + fencing: Add new options --ssl-secure and --ssl-insecure
  + [tests] Update XML metadata of fence agents
  + fence_cisco_ucs & fence_vmware_soap: Logout has to be performed even when fencing fails
  + fence_zvm: Fixes for better upstream inclusion
  + fence_zvm: Add support for 'on', improve documentation
- Added patches:
  + 0001-fence_brocade-Add-support-for-list-action.patch
  + 0002-fencing-Monitor-is-not-working-correctly-without-lis.patch
  + 0003-fence_apc_snmp-Add-support-for-firmware-6.x.patch
  + 0004-fence_zvm-Add-support-for-on-and-status.patch
  + 0005-fence_zvm-Add-current-XML-metadata-to-test-suite.patch
  + 0006-build-Fix-automake-files-so-make-distcheck-works.patch
  + 0007-fencing-Add-new-options-ssl-secure-and-ssl-insecure.patch
  + 0008-tests-Update-XML-metadata-of-fence-agents.patch
  + 0009-fence_cisco_ucs-fence_vmware_soap-Logout-has-to-be-p.patch
  + 0010-fence_zvm-Fixes-for-better-upstream-inclusion.patch
  + 0011-fence_zvm-Add-support-for-on-improve-documentation.patch
- Add dependency on python-requests
* Tue Jul  1 2014 kgronlund@suse.com
- Update to 4.0.10:
  * fence_scsi is reimplemented on top of fencing library
  * fence_zvm support distributed z/VM systems
  * support for --delay was added to fence_zvm
  * unmaintained fence agents were removed:
  * fence_baytech, fence_bullpap, fence_cpint, fence_mcdata,
  * fence_rackswitch, fence_vixel, fence_xcat
  * we do not plan to remove other agents
  * update fence_rsb to work with new firmware
* Tue Jul  1 2014 kgronlund@suse.com
- Update to 4.0.10:
  * fence_scsi is reimplemented on top of fencing library
  * fence_zvm support distributed z/VM systems
  * support for --delay was added to fence_zvm
  * unmaintained fence agents were removed:
  * fence_baytech, fence_bullpap, fence_cpint, fence_mcdata,
  * fence_rackswitch, fence_vixel, fence_xcat
  * we do not plan to remove other agents
  * update fence_rsb to work with new firmware
* Mon May 19 2014 kgronlund@suse.com
- Don't build in parallell (bnc#878580)
* Thu May 15 2014 kgronlund@suse.com
- Update to version 4.0.9 (bnc#877996)
  + Allow ssl connections to fallback to SSL3.0 negotiation
  + fence_vmware_soap: fix short/long option parsing traceback
  + fence_raritan: new fence agent for Raritan Dominion PX
  + fencing: Replace printing to stderr with proper logging solution
  + fence_wti: Action 'list' prints also named groups
  + fence_ipmilan: send empty password, if password is not entered
  + fence_vmware: Invalid arguments for vmware_get_outlets_vi()
  + fence_amt: sending password over env
  + fencing: Introduce new device option 'no_status'
  + fence_pve: new fence-agent for Proxmox VE
  + fence_ovh: --delay should be applied before attempt to login
- Exclude dummy fence agent fence_dummy (bnc#877950)
- Remove obsolete fence-agents-add-longdesc.patch
* Tue Feb 18 2014 kgronlund@suse.com
- Update to version 4.0.7
  + support for firmware v1.40 for WTI (MPC series)
  + nss_wrapper used for fence_ilo was replaced by gnutls-cli
  + --delay was not respected in fence_vmware_soap
  + fabric fence agents have 'off' as default action
  + fence_scsi now generates correct key on corosync clusters
  + regression was found in fence_ipmilan where -P and -L were
    interchanged on command line
    (there was no problem with long options and input from STDIN)
  + fence_vmware_soap now fails with proper error message when user does
    not have enough privileges
* Sat Jan 11 2014 kgronlund@suse.com
- Update to version 4.0.6
  + support for Dell Drac MC was added to fence_drac5
  + support for Tripplite PDU was added to fence_apc
    (thanks to Bogdan Dobrelya)
  + support for AMT was added as new fence agent fence_amt
    (thanks to Ondrej Mular)
  + support for identification of  virtual machine using UUID was
    added to fence_virsh (thanks to Bogdan)
  + fence_ipmilan was ported from C to Python using standard
    fencing library (thanks to Ondrej)
* Thu Oct 31 2013 kgronlund@suse.com
- Update to version 4.0.5
  + fence agent for RSB now works correctly also with newer
    firmware
  + fence agent for WTI now supports not only port numbers but also
    named port groups
  + fence agent for VMWare SOAP now report if user does not have
    enough privileges
  + add a Relax NG for XML metadata of fence agents and require
    them to be correct in order to build a fence agent
  + fix problems found thanks to previous Relax NG
* Mon Sep  9 2013 ygao@suse.com
- Update to version 4.0.3
* Thu Jul  5 2012 dmuhamedagic@suse.com
- add longdesc as copy of shortdesc to produce valid XML (bnc#770043)
* Tue Jun 26 2012 dmuhamedagic@suse.com
- remove fence-ack-manual from supported, it has effect only with
  fenced
- add links to /usr/lib64/stonith/plugins/rhcs
* Thu Jun 21 2012 lmb@novell.com
- Rename two packages to SUSE package names in Requires
- Split into fence-agents and fence-agents-unsupported
- SUSE-fy spec file
* Thu Nov  3 2011 msvec@suse.com
- Initial version 3.1.6
